==> zio-aws-iot1clickdevices_2.13-5.17.126.2-sources.jar: zio/aws/iot1clickdevices/model/UnclaimDeviceRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class UnclaimDeviceRequest(deviceId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest = {
    import UnclaimDeviceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest
      .builder()
      .deviceId(__string.unwrap(deviceId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.iot1clickdevices.model.UnclaimDeviceRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.UnclaimDeviceRequest.wrap(buildAwsValue())
}
object UnclaimDeviceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.UnclaimDeviceRequest =
      zio.aws.iot1clickdevices.model.UnclaimDeviceRequest(deviceId)
    def deviceId: __string
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest
  ) extends zio.aws.iot1clickdevices.model.UnclaimDeviceRequest.ReadOnly {
    override val deviceId: __string =
      zio.aws.iot1clickdevices.model.primitives.__string(impl.deviceId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest
  ): zio.aws.iot1clickdevices.model.UnclaimDeviceRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iot1clickdevices_2.13-5.17.162.3-sources.jar: zio/aws/iot1clickdevices/model/UnclaimDeviceRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class UnclaimDeviceRequest(deviceId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest = {
    import UnclaimDeviceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest
      .builder()
      .deviceId(deviceId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.iot1clickdevices.model.UnclaimDeviceRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.UnclaimDeviceRequest.wrap(buildAwsValue())
}
object UnclaimDeviceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.UnclaimDeviceRequest =
      zio.aws.iot1clickdevices.model.UnclaimDeviceRequest(deviceId)
    def deviceId: __string
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest
  ) extends zio.aws.iot1clickdevices.model.UnclaimDeviceRequest.ReadOnly {
    override val deviceId: __string = impl.deviceId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UnclaimDeviceRequest
  ): zio.aws.iot1clickdevices.model.UnclaimDeviceRequest.ReadOnly = new Wrapper(
    impl
  )
}
